@@ -280,6 +280,20 @@ static struct hdr lhdr[] = {
   {"RmsAmp", SAVE_FKFLT_DEF, 356,  1, " RMS Absolute Amplitude       " },
   {"      ", SAVE_DUMMY_DEF, 357,  1, " ..continued RmsAmp           " },
   {"VelTyp", SAVE_SHORT_DEF, 358,  1, " Velocity Type (0=RMS, 1=Avg, 2=Int, 3=Inst" },
+  {"WlfCol", SAVE_SHORT_DEF, 359,  1, " Wavelet Low Frequency cutoff level" },
+  {"WavBas", SAVE_SHORT_DEF, 360,  1, " Wavelet Basis" },
+  {"WavMom", SAVE_SHORT_DEF, 361,  1, " Wavelet Moment" },
+  {"WlfCo1", SAVE_SHORT_DEF, 362,  1, " Wavelet Low Frequency cutoff level" },
+  {"WavBa1", SAVE_SHORT_DEF, 363,  1, " Wavelet Basis" },
+  {"WavMo1", SAVE_SHORT_DEF, 364,  1, " Wavelet Moment" },
+  {"WlfCo2", SAVE_SHORT_DEF, 365,  1, " Wavelet Low Frequency cutoff level" },
+  {"WavBa2", SAVE_SHORT_DEF, 366,  1, " Wavelet Basis" },
+  {"WavMo2", SAVE_SHORT_DEF, 367,  1, " Wavelet Moment" },
+  {"FreQst", SAVE_FKFLT_DEF, 368,  1, " Frequency Start" },
+  {"      ", SAVE_DUMMY_DEF, 369,  1, " Frequency Start (cont)" },
+  {"FreQnd", SAVE_FKFLT_DEF, 370,  1, " Frequency End" },
+  {"      ", SAVE_DUMMY_DEF, 371,  1, " Frequency End (cont)" },
+
 /*
  * Unclaimed line-header space. The old "velocity information" block
  * of the line header began at byte 601 and extended to byte 1000.
@@ -731,6 +745,19 @@ static struct hdr lhdr[] = {
   {"RmsAmp", SAVE_FKFLT_DEF, 178,  1, " RMS Absolute Amplitude       " },
   {"      ", SAVE_DUMMY_DEF, 179,  1, " ..continued RmsAmp           " },
   {"VelTyp", SAVE_SHORT_DEF, 180,  1, " Velocity Type (0=RMS, 1=Avg, 2=Int, 3=Inst" },
+  {"WlfCol", SAVE_SHORT_DEF, 181,  1, " Wavelet Low Frequency cutoff level" },
+  {"WavBas", SAVE_SHORT_DEF, 182,  1, " Wavelet Basis" },
+  {"WavMom", SAVE_SHORT_DEF, 183,  1, " Wavelet Moment" },
+  {"WlfCo1", SAVE_SHORT_DEF, 184,  1, " Wavelet Low Frequency cutoff level" },
+  {"WavBa1", SAVE_SHORT_DEF, 185,  1, " Wavelet Basis" },
+  {"WavMo1", SAVE_SHORT_DEF, 186,  1, " Wavelet Moment" },
+  {"WlfCo2", SAVE_SHORT_DEF, 187,  1, " Wavelet Low Frequency cutoff level" },
+  {"WavBa2", SAVE_SHORT_DEF, 188,  1, " Wavelet Basis" },
+  {"WavMo2", SAVE_SHORT_DEF, 189,  1, " Wavelet Moment" },
+  {"FreQst", SAVE_FKFLT_DEF, 190,  1, " Frequency Start" },
+  {"      ", SAVE_DUMMY_DEF, 191,  1, " Frequency Start (cont)" },
+  {"FreQnd", SAVE_FKFLT_DEF, 192,  1, " Frequency End" },
+  {"      ", SAVE_DUMMY_DEF, 193,  1, " Frequency End (cont)" },
 /*
  * Unclaimed line-header space. The old "velocity information" block
  * of the line header began at byte 977 and extended to byte 2576.
