@@ -255,8 +255,8 @@ need to check return codes ; we should also realloc after looking up indices
 	hlhknt=0;
 	if (verbose != 0) fprintf(prtfile,"\n EBCDIC header:\n");
 	for (i=0;i<40; i++) {
-	  hlh_entry_length=81;
-	  for (j=79; j>=0 && hlh_entry_length>80; j--) {
+	  hlh_entry_length=0;
+	  for (j=79; j>=0 && hlh_entry_length<=0; j--) {
 	    if (*(buffer+(i*80)+j) != ' ') hlh_entry_length = j-4;
 	    }
 	  if (hlh_entry_length > 0) {
@@ -628,6 +628,25 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 	  }
 	else
 	  memset(header,0,HSTOFF);
+
+/*      Put blanks in line header fields where appropriate
+*/
+	put_hw_val(header,"PrcDat",LINEHEADER,cgdate());
+	put_hw_val(header,"EqpCod",LINEHEADER," ");
+	put_hw_val(header,"CrwNam",LINEHEADER,"      ");
+	put_hw_val(header,"DatTyp",LINEHEADER," ");
+	put_hw_val(header,"DgTrkS",LINEHEADER,"  ");
+	put_hw_val(header,"PrcNam",LINEHEADER,"          ");
+	put_hw_val(header,"PrcDat",LINEHEADER,"        ");
+	put_hw_val(header,"OACLin",LINEHEADER,"        ");
+	put_hw_val(header,"JobNum",LINEHEADER,"        ");
+	put_hw_val(header,"SrtTyp",LINEHEADER,"  ");
+	put_hw_val(header,"GrpInt",LINEHEADER,"    ");
+	put_hw_val(header,"LinDir",LINEHEADER,"    ");
+	put_hw_val(header,"OACUsr",LINEHEADER,"    ");
+	put_hw_val(header,"LinNam",LINEHEADER,"        ");
+	put_hw_val(header,"SPBias",LINEHEADER,"  ");
+	put_hw_val(header,"APIWNo",LINEHEADER,"            ");
 /*
 	Now we actually do the moving of data into the SEGY header
 */
@@ -659,11 +678,19 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 			LINEHEADER,chval);
 		    break;
 		case (SAVE_SHORT_DEF):
-		  if (segy_line_hdr_map[indx].length != -1) 
+		  if (segy_line_hdr_map[indx].length != -1) {
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+	            if (strncmp(segy_line_hdr_map[indx].tag,"Spare",5) == 0) {
+			HTOCS(buffer+
+			  (segy_line_hdr_map[indx].index*sizeof(int)),
+			  segy_line_hdr_map[indx].length);
+			}
+#endif
 		    get_indexed_hw_val(buffer,segy_line_hdr_map[indx].format,
 			segy_line_hdr_map[indx].index,
 			segy_line_hdr_map[indx].length,
 			SEGYLINEHEADER,&sval);
+		    }
 		  else
 		    sval = atoi(segy_line_hdr_map[indx].tag);
 
@@ -673,11 +700,19 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 			LINEHEADER,sval);
 		  break;
 		case (SAVE_INT_DEF):
-		  if (segy_line_hdr_map[indx].length != -1) 
+		  if (segy_line_hdr_map[indx].length != -1) {
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+	            if (strncmp(segy_line_hdr_map[indx].tag,"Spare",5) == 0) {
+			HTOCL(buffer+
+			  (segy_line_hdr_map[indx].index*sizeof(int)),
+			  segy_line_hdr_map[indx].length);
+			}
+#endif
 		    get_indexed_hw_val(buffer,segy_line_hdr_map[indx].format,
 			segy_line_hdr_map[indx].index,
 			segy_line_hdr_map[indx].length,
 			SEGYLINEHEADER,&lval);
+		    }
 		  else
 		    lval = atol(segy_line_hdr_map[indx].tag);
 
@@ -688,11 +723,19 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 		  break;
 		case (SAVE_FLOAT_DEF):
                 case (SAVE_FKFLT_DEF):
-		  if (segy_line_hdr_map[indx].length != -1) 
+		  if (segy_line_hdr_map[indx].length != -1) {
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+	            if (strncmp(segy_line_hdr_map[indx].tag,"Spare",5) == 0) {
+			HTOCL(buffer+
+			  (segy_line_hdr_map[indx].index*sizeof(int)),
+			  segy_line_hdr_map[indx].length);
+			}
+#endif
 		    get_indexed_hw_val(buffer,segy_line_hdr_map[indx].format,
 			segy_line_hdr_map[indx].index,
 			segy_line_hdr_map[indx].length,
 			SEGYLINEHEADER,&rval);
+		    }
 		  else
 		    rval = atof(segy_line_hdr_map[indx].tag);
 
@@ -765,6 +808,11 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 
 	memset(header,0,SZTRHD);
 
+/*      Put blanks in trace header fields where appropriate
+*/
+	put_hw_val(header,"SoPtAl",TRACEHEADER," ");
+	put_hw_val(header,"SoPtBi",TRACEHEADER," ");
+
 	if (verbose >= 2) {
 	    fprintf(prtfile,"\n\n");
 	    fprintf(prtfile," trace       field      field ");
@@ -863,11 +911,19 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 			LINEHEADER,chval);
 		    break;
 		case (SAVE_SHORT_DEF):
-		  if (segy_trace_hdr_map[indx].length != -1) 
+		  if (segy_trace_hdr_map[indx].length != -1) {
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+	            if (strncmp(segy_trace_hdr_map[indx].tag,"Spare",5) == 0) {
+			HTOCS(buffer+
+			  (segy_trace_hdr_map[indx].index*sizeof(int)),
+			  segy_trace_hdr_map[indx].length);
+			}
+#endif
 		    get_indexed_hw_val(buffer,segy_trace_hdr_map[indx].format,
 			segy_trace_hdr_map[indx].index,
 			segy_trace_hdr_map[indx].length,
 			SEGYLINEHEADER,&sval);
+		    }
 		  else
 		    sval = atoi(segy_trace_hdr_map[indx].tag);
 
@@ -877,11 +933,19 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 			LINEHEADER,sval);
 		  break;
 		case (SAVE_INT_DEF):
-		  if (segy_trace_hdr_map[indx].length != -1) 
+		  if (segy_trace_hdr_map[indx].length != -1) {
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+	            if (strncmp(segy_trace_hdr_map[indx].tag,"Spare",5) == 0) {
+			HTOCL(buffer+
+			  (segy_trace_hdr_map[indx].index*sizeof(int)),
+			  segy_trace_hdr_map[indx].length);
+			}
+#endif
 		    get_indexed_hw_val(buffer,segy_trace_hdr_map[indx].format,
 			segy_trace_hdr_map[indx].index,
 			segy_trace_hdr_map[indx].length,
 			SEGYLINEHEADER,&lval);
+		    }
 		  else
 		    lval = atol(segy_trace_hdr_map[indx].tag);
 
@@ -892,11 +956,19 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 		  break;
 		case (SAVE_FLOAT_DEF):
                 case (SAVE_FKFLT_DEF):
-		  if (segy_trace_hdr_map[indx].length != -1) 
+		  if (segy_trace_hdr_map[indx].length != -1) {
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+	            if (strncmp(segy_trace_hdr_map[indx].tag,"Spare",5) == 0) {
+			HTOCL(buffer+
+			  (segy_trace_hdr_map[indx].index*sizeof(int)),
+			  segy_trace_hdr_map[indx].length);
+			}
+#endif
 		    get_indexed_hw_val(buffer,segy_trace_hdr_map[indx].format,
 			segy_trace_hdr_map[indx].index,
 			segy_trace_hdr_map[indx].length,
 			SEGYLINEHEADER,&rval);
+		    }
 		  else
 		    rval = atof(segy_trace_hdr_map[indx].tag);
 
