@@ -37,7 +37,7 @@ char **argv;
 	int offset;
 	char prtfilename[32];
 	char hostname[9],comment[80];
-	long numsmp,smpint,numtrc;
+	int numsmp,smpint,numtrc;
 	short  cdpfold;
 	int line_hdr_indx,trace_hdr_indx;
 	int indx,bytes,help,databytes;
@@ -615,6 +615,11 @@ need to check return codes ; we should also realloc after looking up indices
 				line_hdr_map[indx].tag);
 			}
 		    }
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+	            if (strncmp(segy_line_hdr_map[indx]->tag,"Spare",5) == 0) {
+			HTOCS(&sval,segy_line_hdr_map[indx]->length);
+			}
+#endif
 		  put_indexed_hw_val(header,segy_line_hdr_map[indx]->format,
 			segy_line_hdr_map[indx]->index,
 			segy_line_hdr_map[indx]->length,
@@ -634,6 +639,11 @@ need to check return codes ; we should also realloc after looking up indices
 				line_hdr_map[indx].tag);
 			}
 		    }
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+	         if (strncmp(segy_line_hdr_map[indx]->tag,"Spare",5) == 0) {
+			HTOCL(&lval,segy_line_hdr_map[indx]->length);
+			}
+#endif
 		  put_indexed_hw_val(header,segy_line_hdr_map[indx]->format,
 			segy_line_hdr_map[indx]->index,
 			segy_line_hdr_map[indx]->length,
@@ -654,6 +664,11 @@ need to check return codes ; we should also realloc after looking up indices
 				line_hdr_map[indx].tag);
 			}
 		    }
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+	         if (strncmp(segy_line_hdr_map[indx]->tag,"Spare",5) == 0) {
+			HTOCL(&rval,segy_line_hdr_map[indx]->length);
+			}
+#endif
 		  put_indexed_hw_val(header,segy_line_hdr_map[indx]->format,
 			segy_line_hdr_map[indx]->index,
 			segy_line_hdr_map[indx]->length,
@@ -824,6 +839,11 @@ need to check return codes ; we should also realloc after looking up indices
 				trace_hdr_map[indx].tag);
 			}
 		    }
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+	         if (strncmp(segy_trace_hdr_map[indx]->tag,"Spare",5) == 0) {
+			HTOCS(&sval,segy_trace_hdr_map[indx]->length);
+			}
+#endif
 		  put_indexed_hw_val(header,segy_trace_hdr_map[indx]->format,
 			segy_trace_hdr_map[indx]->index,
 			segy_trace_hdr_map[indx]->length,
@@ -843,6 +863,11 @@ need to check return codes ; we should also realloc after looking up indices
 				trace_hdr_map[indx].tag);
 			}
 		    }
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+	         if (strncmp(segy_trace_hdr_map[indx]->tag,"Spare",5) == 0) {
+			HTOCL(&lval,segy_trace_hdr_map[indx]->length);
+			}
+#endif
 		  put_indexed_hw_val(header,segy_trace_hdr_map[indx]->format,
 			segy_trace_hdr_map[indx]->index,
 			segy_trace_hdr_map[indx]->length,
@@ -863,6 +888,11 @@ need to check return codes ; we should also realloc after looking up indices
 				trace_hdr_map[indx].tag);
 			}
 		    }
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+	         if (strncmp(segy_trace_hdr_map[indx]->tag,"Spare",5) == 0) {
+			HTOCL(&rval,segy_trace_hdr_map[indx]->length);
+			}
+#endif
 		  put_indexed_hw_val(header,segy_trace_hdr_map[indx]->format,
 			segy_trace_hdr_map[indx]->index,
 			segy_trace_hdr_map[indx]->length,
