@@ -4,8 +4,7 @@
  *                    an affiliate of BP America Inc.                  *
  ***********************************************************************/
 /*
-  This file contains the functions for
-  getting the seismic data.
+  This file contains the functions for getting the seismic data.
 */
 
 #include "xdisplayP.h"
@@ -55,12 +54,14 @@ static Widget toggle_sort[3];
 static Widget toggle_scale[5];
 static int sort_mode=0;
 static int scale_mode=1;
-static long id_previous=0;                         /* Previous window. */
+static long id_previous=0;  /* Previous window. */
 static int s_offset=0;
 static Boolean get_data_flag=0;
 static float s_scalar=1.0;
 static float s_exponent=0.0;
 static float hor_zoom=1.0,ver_zoom=1.0;
+static float s_min=0.0;
+static float s_max=1.0;
 static Boolean axis_flag=True;
 static Boolean style_flag=False;
 static Boolean invert_flag=False;
@@ -474,13 +475,11 @@ void get_cancelCB(Widget w, XtPointer client_data, XtPointer call_data)
 
 
 /*
-  This function displays the records,
-  traces and sample parameters to be
+  This function displays the records, traces and sample parameters to be
   send to the data server.
 */
 void data(Widget w, long id, Boolean flag_old)
-         
-                      /* flag_old indicates the old setting are to be used */
+     /* flag_old indicates the old settings are to be used */
 {
   Widget dialog_form;
   Widget dialog_window;
@@ -850,7 +849,7 @@ void data(Widget w, long id, Boolean flag_old)
     case 0: XmToggleButtonSetState(toggle_scale[3],True,False); break;
     case 1: XmToggleButtonSetState(toggle_scale[1],True,False); break;
     case 2: XmToggleButtonSetState(toggle_scale[0],True,False); break;
-    case 3: XmToggleButtonSetState(toggle_scale[0],True,True);  break;
+    case 3: XmToggleButtonSetState(toggle_scale[2],True,False); break;
     case 5: XmToggleButtonSetState(toggle_scale[4],True,False); break;
     }
   } else {
@@ -895,15 +894,13 @@ void data(Widget w, long id, Boolean flag_old)
 
   XmToggleButtonSetState(toggle_sort[sort_mode],True,False);
   if (xdisplay[id].sort) {
-    XmToggleButtonSetState(toggle_sort[0],False,False);
-    XmToggleButtonSetState(toggle_sort[1],True,False);
-    XmToggleButtonSetState(toggle_sort[2],False,False);
-  } else { 
-    if (!flag_old) {
-      XmToggleButtonSetState(toggle_sort[0],True,False);
-      XmToggleButtonSetState(toggle_sort[1],False,False);
-      XmToggleButtonSetState(toggle_sort[2],False,False);
-    }
+     XmToggleButtonSetState(toggle_sort[0],False,False);
+     XmToggleButtonSetState(toggle_sort[1],True,False);
+     XmToggleButtonSetState(toggle_sort[2],False,False);
+  } else if (!flag_old) {
+     XmToggleButtonSetState(toggle_sort[0],True,False);
+     XmToggleButtonSetState(toggle_sort[1],False,False);
+     XmToggleButtonSetState(toggle_sort[2],False,False);
   }
   
   /*
@@ -981,7 +978,7 @@ void data(Widget w, long id, Boolean flag_old)
 			   XmNleftAttachment,XmATTACH_FORM,
 			   NULL);
   
-  sprintf(number,"%d",0);
+  sprintf(number,"%f",s_min);
   text[21]=XmCreateTextVa(form,"text",
 			  XmNtopAttachment,XmATTACH_WIDGET,
 			  XmNtopWidget,text[23],
@@ -1000,7 +997,7 @@ void data(Widget w, long id, Boolean flag_old)
 			   XmNleftWidget,text[21],
 			   NULL);
   
-  sprintf(number,"%d",0);
+  sprintf(number,"%f",s_max);
   text[22]=XmCreateTextVa(form,"text",
 			  XmNtopAttachment,XmATTACH_WIDGET,
 			  XmNtopWidget,text[23],
@@ -1184,16 +1181,8 @@ void data(Widget w, long id, Boolean flag_old)
   
   XtManageChild(dialog_form);
   
-				/* Check min and max of the number
-				   receive from the seismic header. */
-/*if ((nrec[id]<1)||(nrec[id]>20000)||    RJM: dumb check if dataset is 1trc/rec
-      (nsamp[id]<1)||(nsamp[id]>20000)||
-      (ntrace[id]<1)||(ntrace[id]>20000)) {
-*/
-  if( nrec[id] < 1
-  ||  nsamp[id] < 1
-  ||  ntrace[id] < 1 )
-  {
+  /* Check min and max of the number received from the seismic header. */
+  if (nrec[id]<1 || nsamp[id]<1 || ntrace[id]<1) {
     XBell(display,100);
 
     error=XmCreateErrorDialogVa(dialog_form,"error",
@@ -1203,7 +1192,6 @@ void data(Widget w, long id, Boolean flag_old)
 				NULL);
     XtAddCallback(error,XmNokCallback,destroyCB,error);
     XtAddCallback(error,XmNcancelCallback,destroyCB,error);
-
   }
 
   if (disco_flag) {
@@ -1251,8 +1239,7 @@ void data(Widget w, long id, Boolean flag_old)
 
 
 /*
-  This function sets the type
-  of scaling for the data retrieval.
+  This function sets the type of scaling for the data retrieval.
 */
 void set_scale_modeCB(Widget w, XtPointer client_data, XtPointer call_data)
 {
@@ -1318,14 +1305,9 @@ void set_scale_modeCB(Widget w, XtPointer client_data, XtPointer call_data)
 */
 void set_sort_modeCB(Widget w, XtPointer client_data, XtPointer call_data)
 {
-  if (XmToggleButtonGetState(toggle_sort[0]))
-    sort_mode=0;
-
-  if (XmToggleButtonGetState(toggle_sort[1]))
-    sort_mode=1;
-
-  if (XmToggleButtonGetState(toggle_sort[2]))
-    sort_mode=2;
+  if (XmToggleButtonGetState(toggle_sort[0])) sort_mode=0;
+  if (XmToggleButtonGetState(toggle_sort[1])) sort_mode=1;
+  if (XmToggleButtonGetState(toggle_sort[2])) sort_mode=2;
 }
 
 
@@ -1459,22 +1441,21 @@ void check_parametersCB(Widget w, XtPointer client_data, XtPointer call_data)
   long id = (long)client_data;
   char string[1024];
   char *str;
-  int width;
-  float min,max;
-  int n3,s3,e3;
+  int  width;
+  int  n3,s3,e3;
   
   get_data_flag=False;
 
-				/* Flush display so dialog disappears. */
+  /* Flush display so dialog disappears. */
   XmUpdateDisplay(w);
 
-				/* Store window id for previous setting.  */
+  /* Store window id for previous setting.  */
   id_previous=id;
 
   xdisplay[id].sort=sort_mode;
   xdisplay[id].middle=1;
   
-				/* Get data retrieval prarameters. */
+  /* Get data retrieval prarameters. */
 
   XtVaGetValues(expand_text[0],
 		XmNvalue,&str,
@@ -1490,9 +1471,6 @@ void check_parametersCB(Widget w, XtPointer client_data, XtPointer call_data)
   XtVaGetValues(text[0],
 		XmNvalue,&str,
 		NULL);
-/*
-  sscanf(str,"%d",&srec[id]);
-*/
   sscanf(str,"%d",&s3);
   XtFree(str);
   XtVaGetValues(text[1],
@@ -1508,9 +1486,6 @@ void check_parametersCB(Widget w, XtPointer client_data, XtPointer call_data)
   XtVaGetValues(text[3],
 		XmNvalue,&str,
 		NULL);
-/*
-  sscanf(str,"%d",&erec[id]);
-*/
   sscanf(str,"%d",&e3);
   XtFree(str);
   XtVaGetValues(text[4],
@@ -1609,41 +1584,25 @@ void check_parametersCB(Widget w, XtPointer client_data, XtPointer call_data)
     XtVaGetValues(text[21],
 		XmNvalue,&str,
 		NULL);
-    sscanf(str,"%f",&min);
+    sscanf(str,"%f",&s_min);
     XtFree(str);
     XtVaGetValues(text[22],
 		XmNvalue,&str,
 		NULL);
-    sscanf(str,"%f",&max);
+    sscanf(str,"%f",&s_max);
     XtFree(str);
 
-/*  s_scalar=(float)(start_color-end_color-1)/(float)(min-max); RJM: comment out
-: incorrect */
-/*  s_scalar=(float)(end_color-start_color+1)/(float)(max-min); */
-    s_scalar=(float)(end_color-start_color)/(float)(max-min);
+    s_scalar=(float)(end_color-start_color)/(float)(s_max-s_min);
     s_scalar/=100.0;
-#ifdef DEBUG
-	printf( "data.c: check_parametersCB: s_scalar=%f, min=%f, max=%f\n", s_scalar, min, max );
-#endif
 
-    s_offset=(int)((int)start_color-(min*s_scalar*100.0));
+    s_offset=(int)((int)start_color-(s_min*s_scalar*100.0));
     s_offset-=((int)(end_color-start_color+1)/2+start_color);
     s_offset=(int)(100.0*s_offset/(float)(end_color-start_color+1));
 #ifdef DEBUG
+	printf( "data.c: check_parametersCB: s_scalar=%f, s_min=%f, s_max=%f\n", 
+           s_scalar, s_min, s_max );
 	printf( "data.c: check_parametersCB: s_offset=%f\n", s_offset );
 #endif
-
-/*  s_scalar=(float)(start_color-end_color-1)/(float)(min-max); RJM: comment out: incorrect */
-/*
-    s_scalar=(float)(end_color-start_color)/(float)(max-min);
-    s_scalar/=100.0;
-*/
-
-/*
-    s_offset=(int)((int)start_color-(min*s_scalar*100.0));
-*/
-/*  s_offset-=((int)(end_color-start_color+1)/2+start_color); RJM: Horn idiocity */
-/*  s_offset=(int)(100.0*s_offset/(float)(end_color-start_color)); RJM: more Horn idiocity */
   }
 
   XtVaGetValues(text[20],   
@@ -1695,12 +1654,7 @@ void check_parametersCB(Widget w, XtPointer client_data, XtPointer call_data)
   /* DWN modify number of record based on 4D size */
   n3=nrec[id]/n4[id];
 
-				/* Check for valid record parameters. */
-/*
-  if ((srec[id]<1)||(srec[id]>nrec[id])||
-      (erec[id]<1)||(erec[id]>nrec[id])||
-      (srec[id]>erec[id])) {
-*/
+  /* Check for valid record parameters. */
   if ((s3<1)||(s3>n3)||
       (e3<1)||(e3>n3)||
       (s3>e3)) {
@@ -1713,7 +1667,7 @@ void check_parametersCB(Widget w, XtPointer client_data, XtPointer call_data)
   srec[id]=(s4[id]-1)*n3+s3;
   erec[id]=(s4[id]-1)*n3+e3;
 
-				/* Check for valid trace parameters. */
+  /* Check for valid trace parameters. */
   if ((strace[id]<1)||(strace[id]>ntrace[id])||
       (etrace[id]<1)||(etrace[id]>ntrace[id])||
       (strace[id]>etrace[id])) {
@@ -1721,7 +1675,7 @@ void check_parametersCB(Widget w, XtPointer client_data, XtPointer call_data)
     xdisplay[id].init=0;
     return;
   }
-				/* Check for valid sample parameters. */
+  /* Check for valid sample parameters. */
   if ((ssamp[id]<1)||(ssamp[id]>nsamp[id])||
       (esamp[id]<1)||(esamp[id]>nsamp[id])||
       (ssamp[id]>esamp[id])) {
@@ -1884,7 +1838,7 @@ static void getCB(Widget w, XtPointer client_data, XtPointer call_data)
       (((etrace[id]-strace[id])/itrace[id])+1);
     height=((esamp[id]-ssamp[id])/isamp[id])+1;
   } else {
-    /* trace_flag=False; - this made single sample plots break - jmw 1/14/01 */
+    trace_flag=False;
     width=((etrace[id]-strace[id])/itrace[id])+1;
     height=((erec[id]-srec[id])/irec[id])+1;
   }
