@@ -55,73 +55,81 @@ void exposeCB(Widget w, XtPointer client_data, XtPointer call_data)
   char buf_temp[80];
   ClientData *message;
 
-				/* If True then get data else expose window. */
-  if (get_data_flag)
-				/* Check if server is running. */
-    if (!server_flag) {
-      error_message("You must first start the data server.");
-      return;
-    }
-				/* Put valid window ids into a list. */
-  order_count=0;
-  for (n=0; n<MAX_IMAGES; n++)
-    if ((xdisplay[n].init!=0)&&(raster[n]!=NULL)) {
-      order[order_count]=n;
-      order_count++;
-    }
-				/* Sort windows by sequence number. */
-  while (tally>0) {
-    tally=0;
-    for (n=1; n<order_count; n++)
-      if (xdisplay[order[n-1]].sequence>xdisplay[order[n]].sequence) {
-        temp=order[n-1];
-        order[n-1]=order[n];
-        order[n]=temp;
-        tally++;
-      }
+  /* If True then get data else expose window. */
+  if (get_data_flag) {
+     /* Check if server is running. */
+     if (!server_flag) {
+        error_message("You must first start the data server.");
+        return;
+     }
   }
 
-				/* Build XmString list for list widget. */
+  /* Put valid window ids into a list. */
+  order_count=0;
+  for (n=0; n<MAX_IMAGES; n++) {
+     if ((xdisplay[n].init!=0)&&(raster[n]!=NULL)) {
+        order[order_count]=n;
+        order_count++;
+     }
+  }
+
+  /* Sort windows by sequence number. */
+  while (tally>0) {
+     tally=0;
+     for (n=1;n<order_count;n++) {
+        if (xdisplay[order[n-1]].sequence>xdisplay[order[n]].sequence) {
+           temp=order[n-1];
+           order[n-1]=order[n];
+           order[n]=temp;
+           tally++;
+        }
+     }
+  }
+
+  /* Build XmString list for list widget. */
   m=0;
   for (temp=0; temp<order_count; temp++) {
-    n=order[temp];
-    if ((xdisplay[n].init!=0)&&(raster[n]!=NULL)) {
-      window_title(buf,n);
-      sprintf(buf_temp," %4.2f %4.2f ",1.0/xdisplay[n].pick_x,1.0/xdisplay[n].pick_y);
-      strcat(buf,buf_temp);
-      strcat(buf,xdisplay[n].type);
-      if (xdisplay[n].hide_flag)
-        strcat(buf," Hidden ");
-      else
-        strcat(buf,"        ");
-      item_expose[m]=XmStringCreateLtoR(buf,XmSTRING_DEFAULT_CHARSET);
-      m++;
-    }
+     n=order[temp];
+     if ((xdisplay[n].init!=0)&&(raster[n]!=NULL)) {
+        window_title(buf,n);
+        sprintf(buf_temp," %4.2f %4.2f ",
+                1.0/xdisplay[n].pick_x,1.0/xdisplay[n].pick_y);
+        strcat(buf,buf_temp);
+        strcat(buf,xdisplay[n].type);
+        if (xdisplay[n].hide_flag){
+           strcat(buf," Hidden ");
+        } else {
+           strcat(buf,"        ");
+        }
+        item_expose[m]=XmStringCreateLtoR(buf,XmSTRING_DEFAULT_CHARSET);
+        m++;
+     }
   }
 
-				/* Mark the end of the XmString list. */
+  /* Mark the end of the XmString list. */
   item_expose[m]=NULL;
   item_count=m;
   
   n=0;
-				/* If the list is not empty add the items. */
+
+  /* If the list is not empty add the items. */
   if (m!=0) {
     XtSetArg(args[n],XmNlistItems,item_expose); n++;
     XtSetArg(args[n],XmNlistItemCount,m); n++;
   }
   XtSetArg(args[n],XmNlistVisibleItemCount,15); n++;
 
-			/* Use get_data_flag to set the correct title. */
+  /* Use get_data_flag to set the correct title. */
   if (get_data_flag) {
     XtSetArg(args[n],XmNlistLabelString,
-	     XMstr("Double Click to Get Window Parameters")); n++;
+             XMstr("Double Click to Get Window Parameters")); n++;
     XtSetArg(args[n],XmNdialogTitle,
-	     XMstr("Get Window Parameters")); n++;
+             XMstr("Get Window Parameters")); n++;
   } else {
     XtSetArg(args[n],XmNlistLabelString,
-	     XMstr("Double Click on a Window to Expose")); n++;
+             XMstr("Double Click on a Window to Expose")); n++;
     XtSetArg(args[n],XmNdialogTitle,
-	     XMstr("Expose Window")); n++;
+             XMstr("Expose Window")); n++;
   }
   list=XmCreateSelectionDialog(top_level,"Line Header",args,n);
   XtManageChild(list);
@@ -132,18 +140,17 @@ void exposeCB(Widget w, XtPointer client_data, XtPointer call_data)
   XtAddCallback(list,XmNokCallback,expose_windowCB,message);
   XtAddCallback(list,XmNcancelCallback,destroyCB,list);
 
-			/* Use get_data_flag to supply the correct help. */
-  if (get_data_flag)
+  /* Use get_data_flag to supply the correct help. */
+  if (get_data_flag) {
     XtAddCallback(list,XmNhelpCallback,helpCB,"data_list.help");
-  else
+  } else {
     XtAddCallback(list,XmNhelpCallback,helpCB,"expose.help");
+  }
 
+  /* Free all the XmString space. */
+  for (n=0; n<m; n++) XmStringFree(item_expose[n]);
 
-				/* Free all the XmString space. */
-  for (n=0; n<m; n++)
-      XmStringFree(item_expose[n]);
-
-				/* Erases "Apply" button. Confused users. */
+  /* Erases "Apply" button. Confused users. */
   XtUnmanageChild(XmSelectionBoxGetChild(list,XmDIALOG_APPLY_BUTTON));
 }
 
@@ -415,46 +422,46 @@ void globalCB(Widget w, XtPointer client_data, XtPointer call_data)
   
 				/* Put valid window ids into a list. */
   order_count=0;
-  for (n=0; n<MAX_IMAGES; n++)
-    if ((xdisplay[n].init!=0)&&(raster[n]!=NULL)) {
-      order[order_count]=n;
-      order_count++;
-    }
+  for (n=0; n<MAX_IMAGES; n++) {
+     if ((xdisplay[n].init!=0)&&(raster[n]!=NULL)) {
+        order[order_count]=n;
+        order_count++;
+     }
+  }
 
 
-				/* Sort windows by sequence number. */
+  /* Sort windows by sequence number. */
   m=0;
   if (order_count>0) {
-  while (tally>0) {
-    tally=0;
-    for (n=1; n<order_count; n++)
-      if (xdisplay[order[n-1]].sequence>xdisplay[order[n]].sequence) {
-	temp=order[n-1];
-	order[n-1]=order[n];
-	order[n]=temp;
-	tally++;
-      }
-  }
+     while (tally>0) {
+        tally=0;
+        for (n=1; n<order_count; n++) {
+           if (xdisplay[order[n-1]].sequence>xdisplay[order[n]].sequence) {
+              temp=order[n-1];
+              order[n-1]=order[n];
+              order[n]=temp;
+              tally++;
+           }
+        }
+     }
     
-				/* Build XmString list for list widget. */
-  for (temp=0; temp<order_count; temp++) {
-    n=order[temp];
-    if ((xdisplay[n].init!=0)&&(raster[n]!=NULL)) {
-      window_title(buf,n);
-      sprintf(buf_temp," %4.2f %4.2f ",1.0/xdisplay[n].pick_x,1.0/xdisplay[n].pick_y);
-      strcat(buf,buf_temp);
-      strcat(buf,xdisplay[n].type);
-      if (xdisplay[n].hide_flag)
-	strcat(buf," Hidden ");
-      else
-	strcat(buf,"        ");
-      item[m]=XmStringCreateLtoR(buf,XmSTRING_DEFAULT_CHARSET);
-      m++;
-    }
-  }
+     /* Build XmString list for list widget. */
+     for (temp=0; temp<order_count; temp++) {
+        n=order[temp];
+        if ((xdisplay[n].init!=0)&&(raster[n]!=NULL)) {
+           window_title(buf,n);
+           sprintf(buf_temp," %4.2f %4.2f ",1.0/xdisplay[n].pick_x,1.0/xdisplay[n].pick_y);
+           strcat(buf,buf_temp);
+           strcat(buf,xdisplay[n].type);
+           if (xdisplay[n].hide_flag) strcat(buf," Hidden ");
+           else strcat(buf,"        ");
+           item[m]=XmStringCreateLtoR(buf,XmSTRING_DEFAULT_CHARSET);
+           m++;
+        }
+     }
   }
 
-				/* Mark the end of the XmString list. */
+  /* Mark the end of the XmString list. */
   item[m]=NULL;
   item_count=m;
   
@@ -468,13 +475,13 @@ void globalCB(Widget w, XtPointer client_data, XtPointer call_data)
 		XmNvisibleItemCount,10,
 		NULL);
 
+  /* Realize global window once. */
   if (init_list==0) {
-				/* Realize global window once. */
-    XtRealizeWidget(list_window);
-    init_list=1;
+     XtRealizeWidget(list_window);
+     init_list=1;
   }
 
-				/* Map the global window. */
+  /* Map the global window. */
   XtMapWidget(list_window);
 }
 
@@ -557,7 +564,7 @@ void build_listCB(Widget w, XtPointer client_data, XtPointer call_data)
 		NULL);
 
   list_count=0;
-  for (n=0; n<m; n++) {
+  for (n=0;n<m;n++) {
     XmStringGetLtoR(item[n],XmSTRING_DEFAULT_CHARSET,&text);
     sscanf(text,"%*d Window: %d",&window_id);
     if ((xdisplay[window_id].init!=0)&&(raster[window_id]!=NULL)) {
@@ -614,54 +621,52 @@ void expose_severalCB(Widget w, XtPointer client_data, XtPointer call_data)
 */
 void delete_windowCB(Widget w, XtPointer client_data, XtPointer call_data)
 {
-  extern void free_imageCB( Widget, XtPointer, XtPointer ); /* RJM: added */
+  extern void free_imageCB( Widget, XtPointer, XtPointer );
 
   int n;
   long id = (long)client_data;
 
-  if (id==0)
-    return;
+  if (id==0) return;
 
   if (strcmp(xdisplay[id].filename,"Animation")==0)
-    reset_animateCB(NULL,NULL,NULL);
+     reset_animateCB(NULL,NULL,NULL);
 
   if (strcmp(xdisplay[id].type,"Paint")==0) {
-    if( vel_gc ) {	/* RJM: added */
-      XFreeGC(display,vel_gc);
-      vel_gc = (GC)NULL;
-    }
-    paint_index=0;
-    body_init=False;
+     if( vel_gc ) {
+        XFreeGC(display,vel_gc);
+        vel_gc = (GC)NULL;
+     }
+     paint_index=0;
+     body_init=False;
   } else if (strcmp(xdisplay[id].type,"Model")==0) {
-    delete_body_list();
-    quit_model();
+     delete_body_list();
+     quit_model();
   }
-				/* Make sure the window being deleted is
-				   not be using in the animation window. */
+  /* Make sure the window being deleted is
+     not be using in the animation window. */
   if (animate_flag) {
-    for (n=0; n<animate_count; n++)
-      if (animate_list[n]==id) {
-	n=animate_count;
-        if (optimize_errors==False) {
-	  error_message("Cannot delete a window that is being used in the animation window.");
-          optimize_errors=True;
+     for (n=0; n<animate_count; n++)
+        if (animate_list[n]==id) {
+           if (optimize_errors==False) {
+              error_message("Cannot delete a window that is being used in the animation window.");
+              optimize_errors=True;
+           }
+           return;
         }
-        return;
-      }
   }
 
   for (n=0; n<MAX_IMAGES; n++)
-    if ((xdisplay[n].init!=0)&&(raster[n]!=NULL)) {
-      if (strcmp(xdisplay[n].type,"Interleave")==0) {
-	if (xdisplay[n].inter_parent==id) {
-          if (optimize_errors==False) {
-	    error_message("Cannot delete a window that is being used in an interleave window.");
-            optimize_errors=True;
-          }
-          return;
-	}
-      }
-    }
+     if ((xdisplay[n].init!=0)&&(raster[n]!=NULL)) {
+        if (strcmp(xdisplay[n].type,"Interleave")==0) {
+           if (xdisplay[n].inter_parent==id) {
+              if (optimize_errors==False) {
+                 error_message("Cannot delete a window that is being used in an interleave window.");
+                 optimize_errors=True;
+              }
+              return;
+           }
+        }
+     }
 
   /* RJM: NOTE: instead of having free_imageCB get called via the
      XtDestroyCallback resource added during creation of xdisplay[id].window,
@@ -673,7 +678,7 @@ void delete_windowCB(Widget w, XtPointer client_data, XtPointer call_data)
      CITY MAN.
    */
 
-/* free_imageCB must be called before destroyCB which deletes widgets referenced in this function!! */
+  /* free_imageCB must be called before destroyCB which deletes widgets referenced in this function!! */
   free_imageCB( NULL, (XtPointer)client_data, (XtPointer)NULL );
 
   destroyCB(NULL,(XtPointer)xdisplay[id].window,NULL);
@@ -688,26 +693,39 @@ void delete_windowCB(Widget w, XtPointer client_data, XtPointer call_data)
 void delete_severalCB(Widget w, XtPointer client_data, XtPointer call_data)
 {
   int window;
-  long tmp;
+  long id;
 
   /* Delete the items in reverse order. suggested by--> Bill Felinski. */
 
-/* DWN - this might be the cause of the global window hang problem ?????
-   It certainly corrects the problem.
-   It occurs in XtDestroyWidget via destroyCB via delete_windowCB.
-   Why a backwards loop creates havoc with Motif or X I don't know.
-  for (window=list_count-1; window>=0; window--)
-*/
+  /* DWN - this might be the cause of the global window hang problem ?????
+     It certainly corrects the problem.
+     It occurs in XtDestroyWidget via destroyCB via delete_windowCB.
+     Why a backwards loop creates havoc with Motif or X I don't know.
+     for (window=list_count-1; window>=0; window--)
+  */
 
   optimize_errors=False;
 
-  for (window=0; window<list_count; window++)
-    if (window_list[window]!=0)
-    {	/* RJM: changed to call delete_windowCB */
-       tmp = window_list[window];
-       delete_windowCB(w, (XtPointer)tmp, call_data);
+  /* delete any animated or interleave windows first if called for */
+  for (window=0;window<list_count;window++) {
+     id = window_list[window];
+     if (id!=0) {
+        if (strcmp(xdisplay[id].filename,"Animation")==0 ||
+            strcmp(xdisplay[id].type,"Interleave")==0) {
+           delete_windowCB(w, (XtPointer)id, call_data);
+           window_list[window]=0;
+        }
+     }
+  }
+
+  /* now delete the windows */
+  for (window=0; window<list_count; window++) {
+     id = window_list[window];
+     if (id!=0) {
+       delete_windowCB(w, (XtPointer)id, call_data);
        window_list[window]=0;
     }
+  }
 }
 
 
