@@ -42,150 +42,149 @@ char buf_file[MAX_IMAGES][1024];
 
 void load_image(long id, char *filename)
 {
-  FILE *in;
-  char *error,command[1024], fn[1024];
-  int n,image_count,ierror,flag_value;
-  int	nrecs, ntrcperrec, tottraces;
+   FILE *in;
+   char *error,command[1024], fn[1024];
+   int n,image_count,ierror,flag_value;
+   int	nrecs, ntrcperrec, tottraces;
 
-				/* Open header file. */
-  in=fopen(filename,"r");
-  if (in==NULL) {
-    error_message("Can't open file.");
-    return;
-  }
+   /* Open header file. */
+   in=fopen(filename,"r");
+   if (in==NULL) {
+      error_message("Can't open file.");
+      return;
+   }
 
-				/* Parse buf with directory name. */
-  strcpy(buf,filename);
-  strcpy(&buf[strlen(buf)-4],"xsdI");
-				/* Change to image directory. */
-  chdir(buf);
+   /* Parse buf with directory name. */
+   strcpy(buf,filename);
+   strcpy(&buf[strlen(buf)-4],"xsdI");
+   /* Change to image directory. */
+   chdir(buf);
 
-  error=fgets(buf,1024,in);
-  ierror=sscanf(buf,"%s",command);
-
-  for (n=0; n<(int)strlen(command); n++)
-    if (isascii(command[n])==0)
-      ierror=0;
+   error=fgets(buf,1024,in);
+   ierror=sscanf(buf,"%s",command);
 
+   for (n=0; n<(int)strlen(command); n++) {
+      if (isascii(command[n])==0) ierror=0;
+   }
       
-  if (ierror==0) {
-    error_message("Error reading image file.");
-    return;
-  }
-
-				/* Get next available window id. */
-  image_count=next_image();
-
-				/* Set some initial values for that window. */
-  copy_attributes(image_count,id);
-  xdisplay[image_count].axis_units[0]=1.0;
-  xdisplay[image_count].axis_units[1]=1.0;
-  xdisplay[image_count].axis_units[2]=1.0;
-  xdisplay[image_count].init=-3;
-
-				/* Load all the parameters. */
-  while (error!=NULL) {
-    if (strcmp(command,"File:")==0)
-      sscanf(buf,"File: %s",xdisplay[image_count].filename);
-    else if (strcmp(command,"Comment:")==0)
-      sscanf(buf,"Comment: %s",xdisplay[image_count].comment);
-    else if (strcmp(command,"Type:")==0)
-      sscanf(buf,"Type: %s",xdisplay[image_count].type);
-    else if (strcmp(command,"Sort:")==0)
-      sscanf(buf,"Sort: %d",&xdisplay[image_count].sort); 
-    else if (strcmp(command,"Axis:")==0)
-    {
-      sscanf(buf,"Axis: %d",&flag_value);
-      xdisplay[image_count].axis_flag = flag_value?True:False;
-    }
-    else if (strcmp(command,"Dual:")==0)
-    {
-      sscanf(buf,"Dual: %d",&flag_value);
-      xdisplay[image_count].dual_flag = flag_value?True:False;
-    }
-    else if (strcmp(command,"Record:")==0)
-      sscanf(buf,"Record: %d %d %d %d ",&nrec[image_count],&srec[image_count],
-	     &erec[image_count],&irec[image_count]);
-    else if (strcmp(command,"Trace:")==0)
-      sscanf(buf,"Trace: %d%d %d %d ",&ntrace[image_count],&strace[image_count],
-	     &etrace[image_count],&itrace[image_count]);
-    else if (strcmp(command,"Sample:")==0)
-      sscanf(buf,"Sample: %d %d %d %d ",&nsamp[image_count],&ssamp[image_count],
-	     &esamp[image_count],&isamp[image_count]);
-    else if (strcmp(command,"Value:")==0)
-      sscanf(buf,"Value: %d %e ",&xdisplay[image_count].offset,
-	     &xdisplay[image_count].scalar);
-    else if (strcmp(command,"Scale:")==0) {
-      sscanf(buf,"Scale: %f %f ",&xdisplay[image_count].pick_x,
-	     &xdisplay[image_count].pick_y);
-      xdisplay[image_count].pick_x=1.0/xdisplay[image_count].pick_x;
-      xdisplay[image_count].pick_y=1.0/xdisplay[image_count].pick_y;
-    }
-    else if (strcmp(command,"Units:")==0)
-      sscanf(buf,"Units: %f %f %f %f %f %f ",&xdisplay[image_count].axis_units[0],&xdisplay[image_count].axis_units[1],&xdisplay[image_count].axis_units[2],&xdisplay[image_count].axis_offset[0],&xdisplay[image_count].axis_offset[1],&xdisplay[image_count].axis_offset[2]);
-    else if (strcmp(command,"Time:")==0)
-      sscanf(buf,"Time: %s",xdisplay[image_count].time);
-    else if (strcmp(command,"Date:")==0)
-      sscanf(buf,"Date: %s",xdisplay[image_count].date);
-    else if (strcmp(command,"Image:")==0)
-      sscanf(buf,"Image: %s ",&buf_file[image_count][0]);
-    else if (strcmp(command,"Traces1:")==0)	/* RJM: added Traces[1,3] */
-      sscanf(buf,"%*s %s",trace_data1);
-    else if (strcmp(command,"FileTraces1:")==0)
-    {
-      sscanf(buf,"%*s %s",fn);
-      nrecs = (erec[image_count]-srec[image_count]) / irec[image_count] + 1;
-      ntrcperrec = (etrace[image_count]-strace[image_count]) / itrace[image_count] + 1;
-      tottraces = nrecs * ntrcperrec;
-      loadImageTraceH( fn, trace_data1, tottraces, image_count );
-    }
-    else if (strcmp(command,"Traces2:")==0)
-      sscanf(buf,"%*s %s",trace_data2);
-    else if (strcmp(command,"FileTraces2:")==0)
-    {
-      sscanf(buf,"%*s %s",fn);
-      nrecs = (erec[image_count]-srec[image_count]) / irec[image_count] + 1;
-      ntrcperrec = (etrace[image_count]-strace[image_count]) / itrace[image_count] + 1;
-      tottraces = nrecs * ntrcperrec;
-      loadImageTraceH( fn, trace_data2, tottraces, image_count );
-    }
-    else if (strcmp(command,"Traces3:")==0)
-      sscanf(buf,"%*s %s",trace_data3);
-    else if (strcmp(command,"FileTraces3:")==0)
-    {
-      sscanf(buf,"%*s %s",fn);
-      nrecs = (erec[image_count]-srec[image_count]) / irec[image_count] + 1;
-      ntrcperrec = (etrace[image_count]-strace[image_count]) / itrace[image_count] + 1;
-      tottraces = nrecs * ntrcperrec;
-      loadImageTraceH( fn, trace_data3, tottraces, image_count );
-    }
-    else if (strcmp(command,"End:")==0) {	/* End of a window. */
-      strcpy(xdisplay[image_count].data1,trace_data1); /* RJM: added */
-      strcpy(xdisplay[image_count].data2,trace_data2); /* RJM: added */
-      strcpy(xdisplay[image_count].data3,trace_data3); /* RJM: added */
-
-      image_count=next_image();
-      copy_attributes(image_count,id);
-      xdisplay[image_count].axis_units[0]=1.0;
-      xdisplay[image_count].axis_units[1]=1.0;
-      xdisplay[image_count].axis_units[2]=1.0;
-      
-      xdisplay[image_count].init=-3;
-    }
-    error=fgets(buf,1024,in);
-    ierror=sscanf(buf,"%s",command);
-    if (ierror==0) {
+   if (ierror==0) {
       error_message("Error reading image file.");
       return;
-    }
-  }
-  xdisplay[image_count].init=0;
-  fclose(in);
- 
-				/* Display the possible windows to load. */
-  select_load();
+   }
 
-  return;
+   /* Get next available window id. */
+   image_count=next_image();
+
+   /* Set some initial values for that window. */
+   copy_attributes(image_count,id);
+   xdisplay[image_count].axis_units[0]=1.0;
+   xdisplay[image_count].axis_units[1]=1.0;
+   xdisplay[image_count].axis_units[2]=1.0;
+   xdisplay[image_count].init=-3;
+
+   /* Load all the parameters. */
+   while (error!=NULL) {
+      if (strcmp(command,"File:")==0) {
+         sscanf(buf,"File: %s",xdisplay[image_count].filename);
+      } else if (strcmp(command,"Comment:")==0) {
+         sscanf(buf,"Comment: %s",xdisplay[image_count].comment);
+      } else if (strcmp(command,"Type:")==0) {
+         sscanf(buf,"Type: %s",xdisplay[image_count].type);
+      } else if (strcmp(command,"Sort:")==0) {
+         sscanf(buf,"Sort: %d",&xdisplay[image_count].sort); 
+      } else if (strcmp(command,"Axis:")==0) {
+         sscanf(buf,"Axis: %d",&flag_value);
+         xdisplay[image_count].axis_flag = flag_value?True:False;
+      } else if (strcmp(command,"Dual:")==0) {
+         sscanf(buf,"Dual: %d",&flag_value);
+         xdisplay[image_count].dual_flag = flag_value?True:False;
+      } else if (strcmp(command,"Record:")==0) {
+         sscanf(buf, "Record: %d %d %d %d ", &nrec[image_count],
+                &srec[image_count], &erec[image_count], &irec[image_count]);
+      } else if (strcmp(command,"Trace:")==0) {
+         sscanf(buf, "Trace: %d%d %d %d ", &ntrace[image_count],
+                &strace[image_count], &etrace[image_count], 
+                &itrace[image_count]);
+      } else if (strcmp(command,"Sample:")==0) {
+         sscanf(buf, "Sample: %d %d %d %d ", &nsamp[image_count],
+                &ssamp[image_count], &esamp[image_count], &isamp[image_count]);
+      } else if (strcmp(command,"Value:")==0) {
+         sscanf(buf, "Value: %d %e ", &xdisplay[image_count].offset,
+                &xdisplay[image_count].scalar);
+      } else if (strcmp(command,"Scale:")==0) {
+         sscanf(buf, "Scale: %f %f ", &xdisplay[image_count].pick_x,
+                &xdisplay[image_count].pick_y);
+         xdisplay[image_count].pick_x=1.0/xdisplay[image_count].pick_x;
+         xdisplay[image_count].pick_y=1.0/xdisplay[image_count].pick_y;
+      } else if (strcmp(command,"Units:")==0) {
+         sscanf(buf, "Units: %f %f %f %f %f %f ", 
+                &xdisplay[image_count].axis_units[0],
+                &xdisplay[image_count].axis_units[1],
+                &xdisplay[image_count].axis_units[2],
+                &xdisplay[image_count].axis_offset[0],
+                &xdisplay[image_count].axis_offset[1],
+                &xdisplay[image_count].axis_offset[2]);
+      } else if (strcmp(command,"Time:")==0) {
+         sscanf(buf,"Time: %s",xdisplay[image_count].time);
+      } else if (strcmp(command,"Date:")==0) {
+         sscanf(buf,"Date: %s",xdisplay[image_count].date);
+      } else if (strcmp(command,"Image:")==0) {
+         sscanf(buf,"Image: %s ",&buf_file[image_count][0]);
+      } else if (strcmp(command,"Traces1:")==0) {
+         sscanf(buf,"%*s %s",trace_data1);
+      } else if (strcmp(command,"FileTraces1:")==0) {
+         sscanf(buf,"%*s %s",fn);
+         nrecs = (erec[image_count]-srec[image_count])/irec[image_count] + 1;
+         ntrcperrec = (etrace[image_count]-strace[image_count]) 
+            /itrace[image_count] + 1;
+         tottraces = nrecs * ntrcperrec;
+         loadImageTraceH(fn, trace_data1, tottraces, image_count);
+      } else if (strcmp(command,"Traces2:")==0) {
+         sscanf(buf,"%*s %s",trace_data2);
+      } else if (strcmp(command,"FileTraces2:")==0) {
+         sscanf(buf,"%*s %s",fn);
+         nrecs = (erec[image_count]-srec[image_count]) / irec[image_count] + 1;
+         ntrcperrec = (etrace[image_count]-strace[image_count])/
+            itrace[image_count] + 1;
+         tottraces = nrecs * ntrcperrec;
+         loadImageTraceH(fn, trace_data2, tottraces, image_count);
+      } else if (strcmp(command,"Traces3:")==0) {
+         sscanf(buf,"%*s %s",trace_data3);
+      } else if (strcmp(command,"FileTraces3:")==0) {
+         sscanf(buf,"%*s %s",fn);
+         nrecs = (erec[image_count]-srec[image_count])/irec[image_count]+1;
+         ntrcperrec = (etrace[image_count]-strace[image_count])
+            /itrace[image_count] + 1;
+         tottraces = nrecs * ntrcperrec;
+         loadImageTraceH(fn, trace_data3, tottraces, image_count);
+      } else if (strcmp(command,"End:")==0) {
+         strcpy(xdisplay[image_count].data1,trace_data1);
+         strcpy(xdisplay[image_count].data2,trace_data2);
+         strcpy(xdisplay[image_count].data3,trace_data3);
+
+         image_count=next_image();
+         copy_attributes(image_count,id);
+         xdisplay[image_count].axis_units[0]=1.0;
+         xdisplay[image_count].axis_units[1]=1.0;
+         xdisplay[image_count].axis_units[2]=1.0;
+      
+         xdisplay[image_count].init=-3;
+      }
+      error=fgets(buf,1024,in);
+      command[0]='\0';
+      ierror=sscanf(buf,"%s",command);
+      if (ierror==0) {
+         error_message("Error reading image file.");
+         return;
+      }
+   }
+   xdisplay[image_count].init=0;
+   fclose(in);
+ 
+   /* Display the possible windows to load. */
+   select_load();
+
+   return;
 }
 
 
@@ -207,16 +206,13 @@ void select_load(void)
   ClientData *message;
 
   n=0;
-  XtSetArg(args[n],XtNargc,savedArgc); n++;     /* RJM: added 1/17/97 */
-  XtSetArg(args[n],XtNargv,savedArgv); n++;     /* RJM: added 1/17/97 */
+  XtSetArg(args[n],XtNargc,savedArgc); n++; 
+  XtSetArg(args[n],XtNargv,savedArgv); n++; 
   XtSetArg(args[n],XtNiconPixmap,xsd_pixmap); n++;
   XtSetArg(args[n],XtNvisual,visual); n++;
   XtSetArg(args[n],XtNdepth,screenDepth); n++;
-/*list_window=XtAppCreateShell("xsd","load",
-                               topLevelShellWidgetClass,display,args,n);
-RJM: commented out 1/17/97 */
-  list_window=XtAppCreateShell(ApplicationName, ApplicationClass,	/* RJM: added 1/17/97 */
-                               topLevelShellWidgetClass,display,args,n);
+  list_window=XtAppCreateShell(ApplicationName, ApplicationClass,
+                               topLevelShellWidgetClass, display, args, n);
   quit_frame(list_window);
 
   list_form=XmCreateFormVa(list_window,"form",
@@ -228,28 +224,30 @@ RJM: commented out 1/17/97 */
 			   NULL);
   XtAddCallback(list_form,XmNhelpCallback,helpCB,"images.help");
 
-  label=XmCreateLabelVa(list_form,"Image List (Double click on an item to delete from list)",
-			XmNtopAttachment,XmATTACH_FORM,
-			XmNleftAttachment,XmATTACH_FORM,
-			NULL);
+  label=XmCreateLabelVa(list_form, "Image List (Double click on an item to delete from list)",
+                        XmNtopAttachment,XmATTACH_FORM,
+                        XmNleftAttachment,XmATTACH_FORM,
+                        NULL);
   
   frame=XmCreateFrameVa(list_form,"frame",
-			XmNtopAttachment,XmATTACH_WIDGET,
-			XmNtopWidget,label,
-			XmNrightAttachment,XmATTACH_FORM,
-			XmNleftAttachment,XmATTACH_FORM,
-			NULL);
+                        XmNtopAttachment,XmATTACH_WIDGET,
+                        XmNtopWidget,label,
+                        XmNrightAttachment,XmATTACH_FORM,
+                        XmNleftAttachment,XmATTACH_FORM,
+                        NULL);
 
   m=0;
-  for (n=0; n<MAX_IMAGES; n++)
-    if (xdisplay[n].init==-3) {
-      window_title(buf,n);
-      sprintf(buf_temp," %4.2f %4.2f ",1.0/xdisplay[n].pick_x,1.0/xdisplay[n].pick_y);
-      strcat(buf,buf_temp);
-      strcat(buf,xdisplay[n].type);
-      item_image[m]=XmStringCreateLtoR(buf,XmSTRING_DEFAULT_CHARSET);
-      m++;
-    }
+  for (n=0; n<MAX_IMAGES; n++) {
+     if (xdisplay[n].init==-3) {
+        window_title(buf, n);
+        sprintf(buf_temp, " %4.2f %4.2f ", 1.0/xdisplay[n].pick_x,
+                1.0/xdisplay[n].pick_y);
+        strcat(buf, buf_temp);
+        strcat(buf, xdisplay[n].type);
+        item_image[m]=XmStringCreateLtoR(buf,XmSTRING_DEFAULT_CHARSET);
+        m++;
+     }
+  }
   item_image[m]=NULL;
     
   list_image=XmCreateScrolledListVa(frame,"Window List",
@@ -258,14 +256,13 @@ RJM: commented out 1/17/97 */
 				    NULL);
   XtAddCallback(list_image,XmNdefaultActionCallback,delete_itemCB,0);
   if (m!=0) {
-    XtVaSetValues(list_image,
-		  XmNitemCount,m,
-		  XmNitems,item_image,
-		  NULL);
+     XtVaSetValues(list_image,
+                   XmNitemCount,m,
+                   XmNitems,item_image,
+                   NULL);
   }
 
-  for (n=0; n<m; n++)
-    XmStringFree(item_image[n]);
+  for (n=0; n<m; n++) XmStringFree(item_image[n]);
   
   row_column=XmCreateRowColumnVa(list_form,"row_column",
 				 XmNtopAttachment,XmATTACH_WIDGET,
